@@ -2,7 +2,7 @@ package App::Yath;
 use strict;
 use warnings;
 
-our $VERSION = '1.000084';
+our $VERSION = '1.000085';
 
 use Test2::Harness::Util::HashBase qw{
     -config
@@ -213,7 +213,11 @@ sub _command_from_argv {
             return 'help';
         }
 
-        last if $arg eq 'do';
+        if ($arg eq 'do') {
+            splice(@$argv, $idx, 1);
+            last;
+        }
+
         last if $arg eq '::';
         next if $arg =~ /^-/;
 
